# Release History

### 0.2 (2017-08-25)
* Status Beta
* Versioning in sync, setup reads it from the program
* History (this file) added
* Property decorators instead of traditional getters
* README improved

### 0.1 (2017-08-24)
**Initial release**
